Class: Aws::AccountAccess::Types::ErrorDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-accountaccess/types.rb

Overview

Contains information about an error that occurred during application processing.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code that identifies the type of error.

Returns:

  • (String)


300
301
302
303
304
305
# File 'lib/aws-sdk-accountaccess/types.rb', line 300

class ErrorDetails < Struct.new(
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A human-readable message that describes the error.

Returns:

  • (String)


300
301
302
303
304
305
# File 'lib/aws-sdk-accountaccess/types.rb', line 300

class ErrorDetails < Struct.new(
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end