Class: Aws::AccountAccess::Types::ErrorDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::AccountAccess::Types::ErrorDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-accountaccess/types.rb
Overview
Contains information about an error that occurred during application processing.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The error code that identifies the type of error.
-
#message ⇒ String
A human-readable message that describes the error.
Instance Attribute Details
#code ⇒ String
The error code that identifies the type of error.
300 301 302 303 304 305 |
# File 'lib/aws-sdk-accountaccess/types.rb', line 300 class ErrorDetails < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A human-readable message that describes the error.
300 301 302 303 304 305 |
# File 'lib/aws-sdk-accountaccess/types.rb', line 300 class ErrorDetails < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |